#!/usr/bin/env python
#
#------------------------------------------------------------------------------------------------
# Extracts the versions for the daemons, applications -n, driver, browsers and anti-phishing plugins
#------------------------------------------------------------------------------------------------
#
#----------------------------------------------------------------------------------------------------
#							NEW - added by cradacina February 2019
#
#	1. Chrome Version + TLL version in BDProfile_output 
#	2. Agent version in BDProfile_output
#	3. Engines version in BDProfile_output
#	4. VPN version in BDProfile_output 
#	5. Firewall status, FileVault status, startup disks, Software Info and Chip (Controler info in System_Profile_output
#	6. BDProfiler runs even if Bitdefender folder is not found
#	7. Function for gathering files/folders: 
#		#AntivirusLogs(): gathers the Logs folder from /Library/Application Support/Antivirus for Mac/
#		#AntivirusExclusions(): gathers the exclusions.plist file 
#		#BDCrashProfiler(): gathers system and user crash logs and kernel panics (copied from BDProfiler for enterprise)
#		#AppSuppLogs(): gathers the  Bitdefender folder from /Library/Application Support/
#		#Preferences(): gathers the /Library/Preferences/com.bitdefender.antivirusformac.plist file
#		#BitdefenderLogs(): gathers the /Library/Logs/Bitdefender folder
#		#UserPreferences(): gathers the ~/Library/Preferences/com.bitdefender.antivirusformac.plist file
#		#UserLogs(): gathers the ~/Library/Logs/Bitdefender
#	8. New aspect for BDProfile_output
#	9. Parental advisor version in BDProfile_output
#	
# bdmac@bitdefender.com
# Copyright 2011 Bitdefender. All rights reserved.
#
#	$Rev: 9628 $:  Revision of last commit
#	$Date: 2015-07-21 18:14:01 +0300 (Tue, 21 Jul 2015) $:  Date of last commit
#

from optparse import OptionParser, OptionGroup
import commands
import os
import sys
#import zipfile
import shutil
import time
import logging
import plistlib
import codecs
#import glob
import platform
from subprocess import Popen, PIPE, call



#########################################
# Display a simple welcome message first.
#########################################

print ""
print "Welcome to the Bitdefender Profiler Tool."
print ""

#####################################################
##### Define the command line options list ##########
#####################################################

parser  = OptionParser(usage = "usage: %prog [options]    \n"
							   "       default options:	obtain versions, verbose off, system profiler detail level mini\n"
							   "       default destination:		~/Desktop/Bitdefender_Profile_output.zip\n",
					   version =  "%prog " + " $Rev: 9628 $".strip("$ ").split(' ')[1] )
parser.add_option("-o", "--output", dest="path", action='store', type="string", default="", help="The output file path. Eg: /Users/Shared/BitdefenderProfile_output.zip")
parser.add_option("-n", "--noprofile", dest="noprofile", action='store_true', default=False, help="Use this option if you don't want to provide a system profile file") 
parser.add_option("-p", "--profile", dest="level", action='store', type='choice', choices=["mini", "basic", "full"], default=False, help="Choose system profiler detail level - mini, basic, full")
parser.add_option("-v", "--verbose", dest="verbose", action='store_true', default=False, help="Run script in verbose mode, showing commands as they are run")  

guiGroup = OptionGroup(parser, "GUI options", "Options useful when running the script from a GUI application.")
guiGroup.add_option("-l", "--noelevation", dest="noelevation", action='store_true', default=False, help="Don't ask the user for elevation (needed to show the root BD daemons)")
guiGroup.add_option("-w", "--nowait", dest="nowait", action='store_true', default=False, help="Go faster when verbose (don't slow down for a nicer log)") 
guiGroup.add_option("-g", "--gui", dest="gui", action='store_true', default=False, help="apply all the GUI options (including verbose)")
parser.add_option_group(guiGroup)

(options, args) = parser.parse_args()

if options.gui:
	options.noelevation	= True
	options.nowait		= True
	options.verbose		= True

commonCommands = [
					'ps -A | grep fender | grep -v grep',
					'launchctl list | grep fender',
					'kextstat | grep fender',
					'cat /var/log/system.log | grep efender',
				]

# !!!:landron:20101228:	separated from the common commands to have the password requested only when needed 
commonCommandsRoot = [ 
						'sudo launchctl list | grep fender',
				]
adminCondition = False

#####################################################
##### Other Constants ###############################
#####################################################

################################################### NEW ####################################################
AntivirusExclusionsFile = os.path.join('/Library', 'Bitdefender', 'AVP', 'antivirus.bundle', 'exclusions.plist')
VPNInfoPath = '/Library/Bitdefender/Central/Modules/com.bitdefender.vpn/Bitdefender\ VPN.app/Contents/Info.plist'
ModulesPath = os.path.join("/Library", "Bitdefender", "Central", "Modules")
BitdefenderAgentLogsFolder = os.path.join("/Library", "Logs", "Bitdefender")
PreferencesFiles	= os.path.join("/Library", "Preferences", "com.bitdefender.antivirusformac.plist")
UserPreferencesFilesPath = os.path.join(os.getenv('HOME'), 'Library', 'Preferences')
AppSupportBitdefenderFolder = os.path.join("/Library", "Application Support", "Bitdefender")
AgentPath			= os.path.join("/Library", "Bitdefender", "Central", "Agent")
#####################################################################################################
install_log 		= '/private/var/log/install.log'
TimeMachine_cmd2 	= "tmutil destinationinfo | grep 'Mount Point' | cut -d ':' -f 2 | sed -e 's/^ *//g' -e 's/ *$//g'"
TimeMachine_cmd3	= 'defaults read /Library/Preferences/com.apple.TimeMachine.plist Destinations'
system_keychain_cmd	= 'ls -lO /L*/Keyc*'
varTmp				= '/private/var/tmp/BDProfile_output/'
bdProfilePath		= os.path.join(varTmp, 'BD_Profile_output.txt')
sysProfilePath		= os.path.join(varTmp, 'System_Profile_output.txt')
Unresolved_items_list = os.path.join("/Library", "Application Support", "Antivirus for Mac", "Logs", "com.bitdefender.coreissues.antivirus.plist")
AntivirusLogsFolder = os.path.join("/Library", "Application Support", "Antivirus for Mac", "Logs")
History_items_list 	= os.path.join("/Library", "Application Support", "Antivirus for Mac", "Logs", "com.bitdefender.coreissues.history.plist")
#BDCoreIssues_History_Log_path = os.path.join(varTmp, 'com.bitdefender.coreissues.history.plist')
#Unresolved_items_list_dest = os.path.join(varTmp, 'com.bitdefender.coreissues.antivirus.plist')
#Unresolved_items_list_withbackslash = '/Library/Application\ Support/Antivirus\ for\ Mac/Logs/com.bitdefender.coreissues.antivirus.plist'
Unresolved_items_list_source =  '/Library/Preferences/com.apple.TimeMachine.plist'
tmpExtensionPath	= '/private/var/tmp/plugin-safari-rbl.safariextension'
tmpTLLExtensionPath	= '/private/var/tmp/TrafficLight.safariextension'
newKitPath 			= '/Library/Bitdefender/AVP/'
oldKitPath = '/Library/Bitdefender/'
userLogsPath = os.path.join(os.getenv('HOME'), 'Library', 'Logs')
systemLogsPath = '/Library/Logs/'
zipFilePath = varTmp + 'BitdefenderProfile_output.zip'
Chrome = '/Applications/Google Chrome.app'
SafariextPath = os.path.expanduser('~/Library/Safari/Extensions/')
safari_pref = os.path.expanduser('~/Library/Preferences/com.apple.Safari.plist')
ChromePreferences = os.path.expanduser('~/Library/Application Support/Google/Chrome/Default/Preferences')
ChromeExtensions = os.path.expanduser('~/Library/Application Support/Google/Chrome/Default/Extensions')
alafile = os.path.expanduser('~/Desktop/alaa.plist')
Agent = '/Agent/agent.app/Contents/MacOS/agent'
files =  ['/Applications/Uninstall Genieo',os.getenv('HOME')+'/Library/LaunchAgents/com.genieo.completer.download.plist','/usr/lib/libgenkit.dylib','/usr/lib/libgenkitsa.dylib','/usr/lib/libimckit.dylib','/usr/lib/libimckitsa.dylib', os.getenv('HOME') + '/Library/LaunchAgents/com.genieo.completer.update.plist','/Library/LaunchAgents/com.genieoinnovation.macextension.plist','/Library/LaunchAgents/com.genieoinnovation.macextension.client.plist','/Library/LaunchAgents/com.genieo.engine.plist','/Library/LaunchAgents/com.genieo.completer.update.plist','/Library/LaunchDaemons/com.genieoinnovation.macextension.client.plist','/Library/PrivilegedHelperTools/com.genieoinnovation.macextension.client','/Library/LaunchAgents/com.vsearch.agent.plist','/Library/LaunchDaemons/com.vsearch.daemon.plist','/Library/LaunchDaemons/com.vsearch.helper.plist','/Library/LaunchDaemons/Jack.plist','/Library/LaunchAgents/com.conduit.loader.agent.plist', os.getenv('HOME')+'/Library/Internet Plug-Ins/ConduitNPAPIPlugin.plugin' ]
dirs = [os.getenv('HOME')+'/Library/Application Support/com.genieoinnovation.Installer/','/Library/Frameworks/GenieoExtra.Framework', '/Applications/Uninstall IM Completer.app', os.getenv('HOME') + '/Library/Application Support/Genieo/','/Library/Application Support/VSearch','/System/Library/Frameworks/VSearch.framework','/Library/PrivilegedHelperTools/Jack','/Applications/Genieo.app','/Library/InputManagers/CTLoader/','/Library/Application Support/SIMBL/Plugins/CT2285220.bundle','/Library/Application Support/Conduit/',os.getenv('HOME')+ '/Library/Application Support/Conduit/']
launchd = '/private/etc/launchd.conf'
SpeedUpMacpath = '/Applications/SpeedUpMac.app'
#BDCoreIssues_History_Log = '/Library/Application\ Support/Antivirus\ for\ Mac/Logs/com.bitdefender.coreissues.history.plist'
#BDCoreIssues_History_Log_without_backslash = '/Library/Application Support/Antivirus for Mac/Logs/com.bitdefender.coreissues.history.plist'
keep_phrases = ["Administrator authorization granted.",
			  "Displaying 'Install Succeeded' UI.",
			  "User picked Standard Install",
			  "Choices selected for installation:",
			  "./preinstall",
			  "./postinstall",
			  "PackageKit",
			  "Running install actions",
			  "Removing temporary director",
			  "Notifying system of updated components",
			  "Opened from:",
			  "packages=(",
			  "launchctl: Couldn't stat",
			  "unload console with sudo:",
			  "Free space on ",
			  "LSExceptions ",
			  "==== Uninstall Channel Product",
			  "unload console with sudo:",
			  "Remove Files&Folders.",
			  "Uninstall Appstore Product",
			  "Antivirus for Mac  Installation Log",
			  "Product archive",
			  "Displaying 'Install Failed' UI."]

#####################################################
##### Enterprise File Constants #####################
#####################################################

EntAppSupportFolder     = "/Library/Application Support/Antivirus for Mac/Enterprise"
EntSettingsFolder       = "/Library/Bitdefender/AVP/enterprise.bundle"
EntSettingsFiles        = ["epag.jso", "epag.jso.bak", "epag.db", "proxy.jso"]

#####################################################
##### Common Function ###############################
#####################################################

def CopyFile(src, dst):
    if os.path.isfile(src):
        shutil.copyfile(src, dst)

def CopyFolder(src, dst):
    if os.path.isdir(src):
        shutil.copytree(src, dst)

#####################################################
##### Daemons and Application Versions Function #####
#####################################################

# http://stackoverflow.com/questions/1383254/logging-streamhandler-and-standard-streams

def PrintState(message, alignmentDots, before=True, error=False):
	log = logging.getLogger()

	if before and alignmentDots:
		if error:
			log.warning('*'*alignmentDots)
		else:
			log.info('*'*alignmentDots)
	if error:
		log.warning(message)
	else:
		log.info(message)
	if alignmentDots:
		if error:
			log.warning('*'*alignmentDots)
		else:
			log.info('*'*alignmentDots)
logging.basicConfig()		
#	logging.getLogger().flush()
	
def BDProfiler():

# Create the temporary folder

	if not os.path.isdir(varTmp):	
		os.mkdir(varTmp)
# Create a file in which to write the commands' output on user's desktop
	bdProfileFile = open(bdProfilePath, 'w')
	print >>bdProfileFile, '#' * len("PROFILER VERSION AND SYSTEM DETAILS")
	print >>bdProfileFile, "PROFILER VERSION AND SYSTEM DETAILS"
	print >>bdProfileFile, '#' * len("PROFILER VERSION AND SYSTEM DETAILS") + '\n'	
	print >>bdProfileFile, '*' * len(os.path.basename(sys.argv[0]) + ' ' + parser.version.split(' ')[1])
	print >>bdProfileFile, os.path.basename(sys.argv[0]) + ' ' + parser.version.split(' ')[1]
	print >>bdProfileFile, '*' * len(os.path.basename(sys.argv[0]) + ' ' + parser.version.split(' ')[1]) + '\n'
	print >>bdProfileFile, '*' * len('OS Version: ' + platform.mac_ver()[0])
	print >>bdProfileFile, 'OS Version: ' + platform.mac_ver()[0]
	print >>bdProfileFile, '*' * len('OS Version: ' + platform.mac_ver()[0]) + '\n'

# Get usernames in /Users
	print >>bdProfileFile, '*' * len("User home folders")
	print >>bdProfileFile, "User home folders"
	print >>bdProfileFile, '*' * len("User home folders") + '\n'
	if not options.nowait:
		time.sleep(1)

	if options.verbose:
		PrintState("Getting the user home folders", 29)
		
	userList = os.listdir('/Users')
	for userName in userList:
		userHomeFolder = '/Users/' + userName 
		if os.path.isdir(userHomeFolder):
			print >>bdProfileFile, userHomeFolder + "\n"
# Adware related stuff - azavoianu, 04 2015
	LA_list = os.listdir('/Library/LaunchAgents/')
	print >>bdProfileFile, '*' * len("LaunchAgents(root)")
	print >>bdProfileFile, "LaunchAgents(root)"
	print >>bdProfileFile, '*' * len("LaunchAgents(root)") + "\n"
	for item in LA_list:
		print >>bdProfileFile, item + "\n"
	if os.path.isdir(os.getenv('HOME') + '/LibraryLaunchAgents'):
		LA_user_list = os.listdir(os.getenv('HOME') + '/Library/LaunchAgents/')
		print >>bdProfileFile, '*' * len("LaunchAgents(user)")
		print >>bdProfileFile, "LaunchAgents(user)"
		print >>bdProfileFile, '*' * len("LaunchAgents(user)") + "\n"
		for item in LA_user_list:
			print >>bdProfileFile, item + "\n"
	LD_list = os.listdir('/Library/LaunchDaemons')
	print >>bdProfileFile, '*' * len("LaunchDaemons(root)")
	print >>bdProfileFile, "LaunchDaemons(root)"
	print >>bdProfileFile, '*' * len("LaunchDaemons(root)") + "\n"
	for item in LD_list:
		print >>bdProfileFile, item + "\n"
	print >>bdProfileFile, '*' * len("Potential Adware files")
	print >>bdProfileFile, "Potential Adware files"
	print >>bdProfileFile, '*' * len("Potential Adware files") + "\n"	
	vsearch_list = os.listdir('/Library/Application Support/')
	for folder in vsearch_list:
		agent_ = '/Library/Application Support' + folder + Agent
		if os.path.isdir(agent_):
			print >>bdProfileFile, 'Files %s were found' % agent_ + '\n'
	s=0
	for i in range (0,len(files)):
			if os.path.isfile(files[i]):
				print >>bdProfileFile,'Files %s , ' % files[i]
				s=1
	if s:
		print >>bdProfileFile, 'were found \n'
	s=0
	for i in range(0,len(dirs)):
			if os.path.isdir(dirs[i]):
				print >>bdProfileFile,'Folders %s ' % dirs[i]
				s=1
	if s:
		print >>bdProfileFile, 'were found \n'	
	if os.path.isfile(launchd):
		if 'setenv DYLD_INSERT_LIBRARIES /usr/lib/libimckit.dylib' in commands.getoutput('cat %s' % launchd):
			print >>bdProfileFile, 'setenv DYLD_INSERT_LIBRARIES /usr/lib/libimckit.dylib is in launchd.conf'
	else:
		print >>bdProfileFile, "launchd.conf doesn't exist\n"



# Daemons, Applications, Libraries Versions

	def processDirectory(args, dirname, filenames):
	
		systemLogsPath = '/Library/Logs/'                                     
		userLogsPath   = os.getenv('HOME') + '/Library/Logs/'
		
		for filename in filenames:
			
			if (processDirectoryPath in newKitPath) or (processDirectoryPath in oldKitPath):
				pathname = os.path.join(dirname, filename)
				basename, extension = os.path.splitext(pathname)
				if ('Resources' not in basename) and (not extension or pathname.endswith('dylib')):
					commandString = 'strings ' + pathname + ' | grep  PROJECT:'
					versionCommand = commands.getstatusoutput(commandString)
					if versionCommand[0] != 0:
						pass
					else:	
						if options.verbose:
							PrintState("Running the \"%s\" command...\n" % commandString, 0)
							if not options.nowait:
								time.sleep(1)
						print >>bdProfileFile, versionCommand[1] 
			elif (processDirectoryPath in systemLogsPath) or (processDirectoryPath in userLogsPath):
				if ('Bitdefender' in filename) or ('Kernel' in filename):
					pathname = os.path.join(dirname, filename)
					shutil.copy(pathname, varTmp)



#	Agent Version
	if os.path.isdir(os.path.join(AgentPath, "Bitdefender CENTRAL.app")):
		agent_version = commands.getoutput('defaults read ' + os.path.join(AgentPath, "Bitdefender CENTRAL.app", "Contents", "Info.plist") + ' CFBundleVersion')
		print >>bdProfileFile, '*' * len('Agent version {}'.format(agent_version))
		print >>bdProfileFile, 'Agent version {}'.format(agent_version)
		print >>bdProfileFile, '*' * len('Agent version {}'.format(agent_version)) + "\n"
	elif os.path.isdir(os.path.join(AgentPath, "Bitdefender Central.app")):
		agent_version = commands.getoutput('defaults read ' + os.path.join(AgentPath, "Bitdefender Central.app", "Contents", "Info.plist") + ' CFBundleVersion')
		print >>bdProfileFile, '*' * len('Agent version {}'.format(agent_version))
		print >>bdProfileFile, 'Agent version {}'.format(agent_version)
		print >>bdProfileFile, '*' * len('Agent version {}'.format(agent_version)) + "\n"
	elif os.path.isdir(os.path.join(AgentPath, "BitdefenderCentral.app")):
		agent_version = commands.getoutput('defaults read ' + os.path.join(AgentPath, "BitdefenderCentral.app", "Contents", "Info.plist") + ' CFBundleVersion')
		print >>bdProfileFile, '*' * len('Agent version {}'.format(agent_version))
		print >>bdProfileFile, 'Agent version {}'.format(agent_version)
		print >>bdProfileFile, '*' * len('Agent version {}'.format(agent_version)) + "\n"
	else:
		print >>bdProfileFile, '*' * len('Bitdefender Agent is not installed')
		print >>bdProfileFile, 'Bitdefender Agent is not installed'
		print >>bdProfileFile, '*' * len('Bitdefender Agent is not installed') + "\n"
#
#	Kit Version
	kit_version = commands.getoutput('defaults read /Library/Bitdefender/AVP/AntivirusforMac.app/Contents/Info.plist CFBundleVersion')
	if os.path.isdir("/Library/Bitdefender/AVP/AntivirusforMac.app/"):
		print >>bdProfileFile, '*' * len('Kit version {}'.format(kit_version))
		print >>bdProfileFile, 'Kit version {}'.format(kit_version)
		print >>bdProfileFile, '*' * len('Kit version {}'.format(kit_version)) + "\n"
	else:
		print >>bdProfileFile, '*' * len('Bitdefender kit is not installed')
		print >>bdProfileFile, 'Bitdefender kit is not installed'
		print >>bdProfileFile, '*' * len('Bitdefender kit is not installed') + "\n"
		
#	Engines Version
	enginesPath = os.path.join("/Library", "Bitdefender", "AVP", "antivirus.bundle")
	engine_list = []
	if os.path.isdir(enginesPath):
		av_list = os.listdir(enginesPath)
		if av_list == []:
			print >>bdProfileFile, '*' * len("No file found in antivirus.bundle")
			print >>bdProfileFile, "No file found in antivirus.bundle"
			print >>bdProfileFile, '*' * len("No file found in antivirus.bundle") + "\n"
		else:
			for item in av_list:
				if "av64bit" in item:
					engine_list.append(item)
			if engine_list == []:
				print >>bdProfileFile, '*' * len("No Engine found")
				print >>bdProfileFile, "No Engine found"
				print >>bdProfileFile, '*' * len("No Engine found") + '\n'
			else:
				print >>bdProfileFile, '*' * len("Engine Version: " + str(engine_list[0]))
				for engine in engine_list:		
					print >>bdProfileFile, "Engine Version: " + str(engine)
				print >>bdProfileFile, '*' * len("Engine Version: " + str(engine_list[0])) + "\n"
	else:
		print >>bdProfileFile, '*' * len("Engine Path not found")
		print >>bdProfileFile, "Engine Path not found"
		print >>bdProfileFile, '*' * len("Engine Path not found") + "\n"		
#		
#
#	VPN Version		
	if os.path.isdir(os.path.join(ModulesPath, 'com.bitdefender.vpn')):
		vpn_version = commands.getoutput('defaults read ' + VPNInfoPath + ' CFBundleVersion')
		print >>bdProfileFile, '*' * len("VPN version {}".format(vpn_version))
		print >>bdProfileFile, "VPN version {}".format(vpn_version)
		print >>bdProfileFile, '*' * len("VPN version {}".format(vpn_version)) + '\n'
	else:
		print >>bdProfileFile, '*' * len("VPN is not installed")
		print >>bdProfileFile, "VPN is not installed"
		print >>bdProfileFile, '*' * len("VPN is not installed") + "\n"
		
#	PADV Version
	if os.path.isdir("/Library/Bitdefender/Central/Modules/com.bitdefender.parentaladvisor/"):
		padv_version = commands.getoutput('defaults read /Library/Application\ Support/Bitdefender/com.bitdefender.parentaladvisor/installCache.plist versionInstalled')
		#padv_version = padv_version.split('=')[1].strip(';')
		print >>bdProfileFile, '*' * len('PADV version {}'.format(padv_version))
		print >>bdProfileFile, 'PADV version {}'.format(padv_version)
		print >>bdProfileFile, '*' * len('PADV version {}'.format(padv_version)) + "\n"
	else:
		print >>bdProfileFile, '*' * len('PADV is not installed')
		print >>bdProfileFile, 'PADV is not installed'
		print >>bdProfileFile, '*' * len('PADV is not installed') + "\n"	

	if options.verbose:
		PrintState("Determining the daemon and application versions",47)
	print >>bdProfileFile, '\n' + '#' * len("DAEMONS AND APPLICATIONS VERSIONS")
	print >>bdProfileFile, "DAEMONS AND APPLICATIONS VERSIONS"
	print >>bdProfileFile, '#' * len("DAEMONS AND APPLICATIONS VERSIONS") + "\n"
	if os.path.exists("/Applications/Xcode.app"):
		if os.path.isdir(newKitPath):
			processDirectoryPath = newKitPath
			os.path.walk(processDirectoryPath, processDirectory, None)
		elif os.path.isdir(oldKitPath):
			processDirectoryPath = oldKitPath
			os.path.walk(processDirectoryPath, processDirectory, None)
		else:	 
			PrintState("Error! Bitdefender folder could not be found. Gathering remnants and other info...", 60, False, True)
			time.sleep(1)
	else:
		 print >>bdProfileFile, "\n Xcode is not installed, the command requires xcode command line tools \n"
		#exit()

		
#	os.path.walk(processDirectoryPath, processDirectory, None)
#	print >>bdProfileFile, "\n"
#	collect history log from application support
#	if os.path.isfile(BDCoreIssues_History_Log_without_backslash):
#		os.system('cp %s %s' %(BDCoreIssues_History_Log, BDCoreIssues_History_Log_path))
#	collect unresolved list from application support
#	if os.path.isfile(Unresolved_items_list_source):
#		os.system('cp %s %s' % (Unresolved_items_list_withbackslash, Unresolved_items_list_dest))
# Crash logs and panics
#	if options.verbose:
#		PrintState("Getting the crash and kernel panic logs", 39)
#		if not options.nowait:
#			time.sleep(1)
	
#	processDirectoryPath   = userLogsPath
#	try:
#		os.path.walk(processDirectoryPath, processDirectory, None )
#		processDirectoryPath = systemLogsPath
#		os.path.walk(processDirectoryPath, processDirectory, None )
#	except:
#		pass
		
			
### Get the versions of Safari, Firefox and the APH extension and plugin
	systemVersion = commands.getoutput('sw_vers -productVersion').split(".")
	# if ('10.5' in systemVersion or '10.6' in systemVersion or '10.7' in systemVersion or '10.8' in systemVersion) and (os.path.isdir(newKitPath)):
	if int(systemVersion[0]) >= 10 and int(systemVersion[1]) > 4:
		if options.verbose:
			PrintState("Fetching the Browser and the Anti-phishing Plugins versions..." , 62)
			if not options.nowait:
				time.sleep(1)
		
		print >>bdProfileFile, '\n\n' + '#' * len("BROWSER DETAILS")
		print >>bdProfileFile, "BROWSER DETAILS"
		print >>bdProfileFile, '#' * len("BROWSER DETAILS") + "\n"
		
# Safari Version
		print >> bdProfileFile, '=' * 20 + ' Safari Info ' + '=' * 20 + '\n'
		safariVersion = commands.getoutput('defaults read /Applications/Safari.app/Contents/Info CFBundleShortVersionString')
		print >>bdProfileFile, '*' * len("Safari Version: {}".format(safariVersion))
		print >>bdProfileFile, "Safari Version: {}".format(safariVersion)
		print >>bdProfileFile, '*' * len("Safari Version: {}".format(safariVersion)) + "\n"
		
		# Installed Safari TLL Plugin Version
		safariTLLPath = os.getenv('HOME') + '/Library/Safari/Extensions/TrafficLight.safariextz'		
		if ( os.path.isfile(safariTLLPath) ):
			unarchTLL			= 'xar -xf ~/Library/Safari/Extensions/TrafficLight.safariextz Info.plist -C /private/var/tmp'						
			os.system(unarchTLL)
			installedSafariTLLVersion  = 'defaults read /private/var/tmp/TrafficLight.safariextension/Info CFBundleShortVersionString'
			installedTLLVersionString	 = commands.getoutput(installedSafariTLLVersion)
			print >>bdProfileFile, '*' * len('TrafficLight for Safari Version: {}'.format(installedTLLVersionString))  
			print >>bdProfileFile, 'TrafficLight for Safari Version: {}'.format(installedTLLVersionString)
			print >>bdProfileFile, '*' * len('TrafficLight for Safari Version: {}'.format(installedTLLVersionString)) + "\n"
			try:	
				shutil.rmtree(tmpTLLExtensionPath)	
			except OSError:
				pass
		else:
			print >>bdProfileFile, '*' * len("Safari TrafficLight not installed")
			print >>bdProfileFile, "Safari TrafficLight not installed"
			print >>bdProfileFile, '*' * len("Safari TrafficLight not installed") + "\n"	
		# Safari extensions	
		print >>bdProfileFile, '*' * len("Safari Extensions")
		print >>bdProfileFile, "Safari Extensions"
		print >>bdProfileFile, '*' * len("Safari Extensions") + "\n"		
		if os.path.isdir(SafariextPath):
			extensions = os.listdir(SafariextPath)
			for item in extensions:
				print >>bdProfileFile, item + "\n"
			print >>bdProfileFile, '*' * len("Verify Safari search engine and homepage for genieo")
			print >>bdProfileFile, "Verify Safari search engine and homepage for genieo"
			print >>bdProfileFile, '*' * len("Verify Safari search engine and homepage for genieo") + "\n"	
			if os.path.isfile(safari_pref):
				f = os.path.expanduser('~/Library/Preferences/com.apple.Safari.plist')
				#plistlib.writePlist('', alafile)
				#os.system('cp %s %s' % (f, alafile))
				#call(['plutil','-convert','xml1', alafile])
				
				try:
					print >>bdProfileFile, '\n Safari SearchEngine %s' % commands.getoutput('defaults read %s SearchProfiderIdentifier' % safari_pref)
					print >>bdProfileFile, '\n Safari SearchEngine %s' % commands.getoutput('defaults read %s ExtensionSettings-com.genieo.safari-K444F5Z2ZH' % safari_pref)
					print >>bdProfileFile, '\n Safari Homepage %s' % commands.getoutput('defaults read %s HomePage' % safari_pref)
				except:
					pass

			else:
				print >>bdProfileFile, "\n com.apple.Safari.plist doesn't exist \n"
		
# Firefox Version		
		print >> bdProfileFile, "\n" + '=' * 20 + ' Firefox Info ' + '=' * 20 + '\n'
		firefoxPath			= '/Applications/Firefox.app/'
		if os.path.isdir(firefoxPath):
			firefoxVersion		= commands.getoutput('defaults read /Applications/Firefox.app/Contents/Info CFBundleShortVersionString')
			print >>bdProfileFile, '*' * len("Firefox Version: {}".format(firefoxVersion))
			print >>bdProfileFile, "Firefox Version: {}".format(firefoxVersion)
			print >>bdProfileFile, '*' * len("Firefox Version: {}".format(firefoxVersion)) + "\n"		
# Installed Firefox TLL Plugin Version
			firefoxProfilePath = os.getenv('HOME') + '/Library/Application Support/Firefox/Profiles'
			if os.path.exists(firefoxProfilePath):
				firefoxTLLProfileList = os.listdir(firefoxProfilePath)
				for profileTLLName in firefoxTLLProfileList[1:]:
					firefoxExtSqPath = os.getenv('HOME') + '/Library/Application Support/Firefox/Profiles/' + profileTLLName + '/extensions.sqlite'
					if os.path.isfile(firefoxExtSqPath):
						extVerSq = Popen(("sqlite3 '%s' 'select version from addon where id=\"trafficlight@bitdefender.com\"'" % firefoxExtSqPath), shell=True, stdout=PIPE).communicate()[0]
						print >>bdProfileFile, '*' * len("Installed Firefox TrafficLight Plugin Version: {}".format(extVerSq))
						print >>bdProfileFile, "Installed Firefox TrafficLight Plugin Version: {}".format(extVerSq)
						print >>bdProfileFile, '*' * len("Installed Firefox TrafficLight Plugin Version: {}".format(extVerSq))
			else:
				print >>bdProfileFile, '*' * len("TrafficLight for Firefox not installed")
				print >>bdProfileFile, "TrafficLight for Firefox not installed"
				print >>bdProfileFile, '*' * len("TrafficLight for Firefox not installed") + "\n"
	# Aph plugin versions			
	#		print >>bdProfileFile, '*' * len("Plugin Versions")
	#		print >>bdProfileFile, "Plugin Versions"
	#		print >>bdProfileFile, '*' * len("Plugin Versions") + "\n"
			
	# Installed Firefox  Extensions
			print >>bdProfileFile, '*' * len("Firefox Extensions")
			print >>bdProfileFile, "Firefox Extensions"
			print >>bdProfileFile, '*' * len("Firefox Extensions") + "\n"
			if os.path.exists(firefoxProfilePath):
				firefoxProfileList = os.listdir(firefoxProfilePath)
				for profileName in firefoxProfileList:
					firefoxExtPath	= os.getenv('HOME') + '/Library/Application Support/Firefox/Profiles/' + profileName + '/extensions/'
					if os.path.isdir(firefoxExtPath):
						ff_extensions = os.listdir(firefoxExtPath)
						for extension in ff_extensions:
							print >>bdProfileFile, extension + "\n"
		else:
			print >>bdProfileFile, '*' * len("Firefox is not Installed")
			print >>bdProfileFile, "Firefox is not Installed"
			print >>bdProfileFile, '*' * len("Firefox is not Installed") + "\n"					

# Chrome Version
		print >> bdProfileFile, "\n" + '=' * 20 + ' Chrome Info ' + '=' * 20 + '\n'
		chromePath = '/Applications/Google Chrome.app'
		if os.path.isdir(chromePath):
			chromeVersion = commands.getoutput('defaults read /Applications/Google\ Chrome.app/Contents/Info.plist CFBundleShortVersionString')
			print >>bdProfileFile, '*' * len("Chrome Version: {} \n".format(chromeVersion))
			print >>bdProfileFile, "Chrome Version: {}".format(chromeVersion)
			print >>bdProfileFile, '*' * len("Chrome Version: {} \n".format(chromeVersion)) + "\n"		
# Installed Chrome TLL version
		#if os.path.isfile(ChromePreferences):
			#inf_ext_chrome = ['cbmjmfcldbpelhknnfjbkobmabafpoed']
			#to_fix_later(get chrome homepage,searchengine and startupurls:
			#f = codecs.open(ChromePreferences,encoding = 'utf-8')
			#for line in f:
			#	if 'http' in repr(line) and 'homepage' in repr(line):
			#		print >>bdProfileFile, 'Chrome HomePage%s' % repr(line)
			#	if '"url"' in repr(line):
			#		print >>bdProfileFile, 'Chrome Search engine %s' % repr(line)
			#	if 'startup_urls' in repr(line):
			#		print >>bdProfileFile, '\n%s Chrome startupUrls' % repr(line)  
			if os.path.isdir(ChromeExtensions):
				chrome_extensions = os.listdir(ChromeExtensions)
				if 'cfnpidifppmenkapgihekkeednfoenal' in os.listdir(ChromeExtensions):
					TLL_version = os.listdir(os.path.join(ChromeExtensions, 'cfnpidifppmenkapgihekkeednfoenal'))
					print >>bdProfileFile, '*' * len("TrafficLight version {} for Chrome: ".format(TLL_version[0]))
					print >>bdProfileFile, "TrafficLight version {} for Chrome: ".format(TLL_version[0])
					print >>bdProfileFile, '*' * len("TrafficLight version {} for Chrome: ".format(TLL_version[0])) + "\n"
				else:
					print >>bdProfileFile, '*' * len("TrafficLight for Chrome is not installed")
					print >>bdProfileFile, "TrafficLight for Chrome is not installed"
					print >>bdProfileFile, '*' * len("TrafficLight for Chrome is not installed") + "\n"
			# Installed Chrome Extensions
				print >>bdProfileFile, '*' * len("Chrome Extensions")
				print >>bdProfileFile, "Chrome Extensions"
				print >>bdProfileFile, '*' * len("Chrome Extensions") + "\n"
				for extension in chrome_extensions:
					print >>bdProfileFile, extension + "\n"
		else:
			print >>bdProfileFile, '*' * len("Chrome is not installed")
			print >>bdProfileFile, "Chrome is not installed"
			print >>bdProfileFile, '*' * len("Chrome is not installed") + "\n"

# Other comands	
	print >>bdProfileFile, "\n" + '#' * len("BITDEFENDER SERVICES")
	print >>bdProfileFile, "BITDEFENDER SERVICES"
	print >>bdProfileFile, '#' * len("BITDEFENDER SERVICES") + "\n"	
	for commandName in commonCommands:				
		commandResult = commands.getoutput(commandName)

		#if commandName == 'defaults read /Library/Bitdefender/AVP/AntivirusforMac.app/Contents/Info.plist CFBundleVersion':
		#	if options.verbose:
		#		PrintState("Finding the installed kit version", 55)
		#		if not options.nowait:
		#			time.sleep(1)
		#	print >>bdProfileFile, '*'*21
		#	print >>bdProfileFile, "Installed Kit Version"
		#	print >>bdProfileFile, '*'*21 
		#	commandResult = commandResult()
		

		if commandName == 'ps -A | grep fender | grep -v grep':
			if options.verbose:
				PrintState("Determining running daemons and/or applications", 47)
				if not options.nowait:
					time.sleep(1)
			print >>bdProfileFile, '*' * len("Running Daemons and/or Applications")
			print >>bdProfileFile, "Running Daemons and/or Applications"
			print >>bdProfileFile, '*' * len("Running Daemons and/or Applications") + "\n"

		if commandName == 'launchctl list | grep fender':
			if options.verbose:
				PrintState("Determining user loaded agents",31)
				if not options.nowait:
					time.sleep(1)
			print >>bdProfileFile, '*' * len("User Loaded Agents")
			print >>bdProfileFile, "User Loaded Agents"
			print >>bdProfileFile, '*' * len("User Loaded Agents") + "\n"
					
		if commandName == 'kextstat | grep fender':
			if options.verbose:
				PrintState("Determining Bitdefender loaded kexts", 24)
				if not options.nowait:
					time.sleep(1)
			print >>bdProfileFile, '*' * len("Bitdefender Loaded Kexts")
			print >>bdProfileFile, "Bitdefender Loaded Kexts"
			print >>bdProfileFile, '*' * len("Bitdefender Loaded Kexts") + "\n" 	
			
		if commandName == 'cat /var/log/system.log | grep efender':
			if options.verbose:
				PrintState("Fetching system log errors",33)
				if not options.nowait:
					time.sleep(1)
			print >>bdProfileFile, '*' * len("System Log")
			print >>bdProfileFile, "System Log"
			print >>bdProfileFile, '*' * len("System Log") + "\n" 
			
		if options.verbose:
			PrintState("Running the \"%s\" command...\n" % commandName, 0)
			if not options.nowait:
				time.sleep(1)	
			
		print >>bdProfileFile, commandResult + "\n"*2
		

#
# Display the sudo usage requirement.
#
	global adminCondition
	userID = commands.getoutput('id -u $USER')
	if userID and not options.noelevation:
		print "\nThe interrogation processes requires administrative privileges"
		print "because some of the installed files cannot be inquired by a normal user.\n"
		answer = raw_input("Would you like to provide an administrator password? [Y/N]\n Answer:")
		if answer in ["y", "Y", "yes", "Yes", "YES"]:
			adminCondition = True

	print >>bdProfileFile, '*' * len("System Loaded Daemons")
	print >>bdProfileFile, "System Loaded Daemons and other details"
	print >>bdProfileFile, '*' * len("System Loaded Daemons") + "\n"
	if adminCondition:
		for commandName in commonCommandsRoot:				
			commandResult = commands.getoutput(commandName)
			#collect log files from /Library/Logs/ (if enabled) -logs folder is already copied
			#list = os.listdir('/Library/Logs/')
			#for item in list:
			#	cmd = "cp /Library/Logs/'%s' '%s'" % (item, varTmp + item)
			#	if 'BDCoreIssues' in item:
			#		os.system(cmd)
			#	if 'com.bitdefender.agent' in item:
			#		cmd = "sudo cp /Library/Logs/'%s' '%s'" % (item, varTmp + item)
			#		os.system(cmd)
			#		cmd2 = "sudo chmod -R 777 '%s' " % (varTmp)
			#		os.system(cmd2)
			#	if 'BDLDaemon' in item:
			#		os.system(cmd)
			if commandName == 'sudo launchctl list | grep fender':
				if options.verbose:
					PrintState("Determining system loaded daemons",33)
					if not options.nowait:
						time.sleep(1)	
				
			if options.verbose:
				PrintState("Running the \"%s\" command...\n" % commandName, 0)
				if not options.nowait:
					time.sleep(1)	
				
			print >>bdProfileFile, commandResult + "\n"*2
	else:
		print >> bdProfileFile, '\n' + ' This piece of information requires admin priveleges ' + '\n'
	print >> bdProfileFile, "\n" + '=' * 20 + ' Install log ' + '=' * 20 + '\n' + "\n"
	if os.path.isfile(install_log):
		with open(install_log) as f:
			f = f.readlines()
		for line in f:
			for phrase in keep_phrases:
				if phrase in line and 'bitdefender' in line:
					print >>bdProfileFile, line
					break				

# Close the BD profile file
	bdProfileFile.close()

# Collect files and logs ####PARTIALLY NEW####
def AntivirusLogs():
	CopyFolder(AntivirusLogsFolder, os.path.join(varTmp, "AntivirusLogs"))
	
def AntivirusExclusions():
	os.mkdir(os.path.join(varTmp, 'Antivirus_Exclusions'))
	CopyFile(AntivirusExclusionsFile, os.path.join(varTmp, 'Antivirus_Exclusions', 'exclusions.plist'))

def AppSuppLogs():
	CopyFolder(AppSupportBitdefenderFolder, os.path.join(varTmp, "App_Support_Bitdefender"))

def Preferences():
	os.mkdir(os.path.join(varTmp, 'Bitdefender_Preferences'))
	CopyFile(PreferencesFiles, os.path.join(varTmp, 'Bitdefender_Preferences', 'com.bitdefender.antivirusformac.plist'))

def BitdefenderLogs():
	CopyFolder(BitdefenderAgentLogsFolder, os.path.join(varTmp, "Bitdefender_Logs"))

def UserPreferences():
	if os.path.isdir(UserPreferencesFilesPath):
		os.mkdir(os.path.join(varTmp, 'Bitdefender_User_Preferences'))
		CopyFile(os.path.join(UserPreferencesFilesPath, 'com.bitdefender.antivirusformac.plist'), os.path.join(varTmp, 'Bitdefender_User_Preferences', 'com.bitdefender.antivirusformac.plist'))
		CopyFile(os.path.join(UserPreferencesFilesPath, 'com.bitdefender.vpn.plist'), os.path.join(varTmp, 'Bitdefender_User_Preferences', 'com.bitdefender.vpn.plist'))
		CopyFile(os.path.join(UserPreferencesFilesPath, 'com.bitdefender.IMP.UserSettings.plist'), os.path.join(varTmp, 'Bitdefender_User_Preferences', 'com.bitdefender.IPM.UserSettings.plist'))

def UserLogs():
	if os.path.isdir(userLogsPath):
		CopyFolder(os.path.join(userLogsPath, 'Bitdefender'), os.path.join(varTmp, 'Bitdefender_User_Logs'))
		
def BDEntProfiler():
	CopyFolder(EntAppSupportFolder, os.path.join(varTmp, "Enterprise"))
	if os.path.isdir(EntSettingsFolder):
		for file in EntSettingsFiles:
			CopyFile(os.path.join(EntSettingsFolder, file), os.path.join(varTmp, file))


#####################################################
##### System Profiler Function ######################
#####################################################

def SystemProfiler():

# Make a file with the system profile according to the default or selected option
	if options.noprofile:
		return 0
	global adminCondition
	mini_profile  = 'system_profiler -detailLevel mini'
	basic_profile = 'system_profiler -detailLevel basic'
	full_profile  = 'system_profiler -detailLevel full'
	
	sysProfileFile = open(sysProfilePath, 'w')
	
	print >>sysProfileFile, '*'*100
	print >>sysProfileFile, os.path.basename(sys.argv[0]) + ' ' + parser.version.split(' ')[1]
	print >>sysProfileFile, '*'*100 + '\n'
	print >>sysProfileFile, commands.getoutput(system_keychain_cmd)
	print >>sysProfileFile, '*'*100 + '\n'
	if os.path.isdir(SpeedUpMacpath):
		print >>sysProfileFile, 'SpeedUpMac este instalat pe sistem, provoaca conflict cu fisierul de preferinte com.bitdefender.antivirusformac.plist' + '\n'
	else:
		print >>sysProfileFile, 'SpeedUpMac nu este instalat pe sistem' + '\n'
	print >>sysProfileFile, '*'*50 + ' Gatekeeper Info ' + '*'*50 + '\n'
	GateKeeper_setting = 'spctl --status'
	gatekeeper = commands.getoutput(GateKeeper_setting)
	if 'enabled' in gatekeeper:
		print >>sysProfileFile, 'Gatekeeper is set to install apps only from Appstore and/or known developers' + '\n'
	elif 'disabled' in gatekeeper:
		print >>sysProfileFile, 'Gatekeeper is set to install apps from anywhere' + '\n'
	print >>sysProfileFile, '*'*50 + ' Time Machine Info ' + '*'*50 + '\n'
	TimeMachine_cmd = 'tmutil destinationinfo'
	if 'No destination alias' in commands.getoutput(TimeMachine_cmd):
		print >>sysProfileFile, 'Time Machine not configured'
	else:
		print >>sysProfileFile, commands.getoutput(TimeMachine_cmd)
		print >>sysProfileFile, commands.getoutput(TimeMachine_cmd2)
		if os.path.isfile('/Library/Preferences/com.apple.TimeMachine.plist'):
			print >>sysProfileFile, commands.getoutput(TimeMachine_cmd3)
	print >>sysProfileFile, '\n'		
	if options.verbose:
		PrintState("Creating %s system profile. Please wait, this might take a while..." % options.level, 73)
		if not options.nowait:
			time.sleep(1)
	if options.level == "mini":
		print >>sysProfileFile, commands.getoutput(mini_profile) 
	elif options.level == "basic":
		print >>sysProfileFile, commands.getoutput(basic_profile)
	elif options.level == "full":
		print >>sysProfileFile, commands.getoutput(full_profile)


	print >> sysProfileFile, '*' * 50 + ' Software Info ' + '*' * 50 + '\n'
	print >> sysProfileFile, commands.getoutput('/usr/sbin/system_profiler SPSoftwareDataType') + '\n'
	#print >> sysProfileFile, '*' * 16 + '\n'
	print >>sysProfileFile, '*' * 50 + ' Hardware Info ' + '*' * 50 + '\n'
	print >>sysProfileFile , commands.getoutput('/usr/sbin/system_profiler SPHardwareDataType') + '\n'
	#print >>sysProfileFile, '*'*16 + '\n'
	print >> sysProfileFile, '*' * 50 + ' Chip Info ' + '*' * 50 + '\n'
	print >> sysProfileFile, commands.getoutput('/usr/sbin/system_profiler SPiBridgeDataType') + '\n'
	#print >> sysProfileFile, '*' * 16 + '\n'
	if platform.mac_ver()[0].split(".")[1] >= 14:
		print >> sysProfileFile, '*' * 50 + ' Full Disk Access Info in this order: client(e.g. /path/to/process if process or bundle_id if app), allowed ' + '*' * 50 + '\n'
		print >> sysProfileFile, commands.getoutput('sqlite3 /Library/Application\ Support/com.apple.TCC/TCC.db "select client, allowed from access where service=\'kTCCServiceSystemPolicyAllFiles\'"') + '\n'
		#print >> sysProfileFile, '*' * 16 + '\n'
		
	if platform.mac_ver()[0].split(".")[1] >= 13:
		print >> sysProfileFile, '*' * 50 + ' Kext Approved Info in this order: bundle_id, allowed, developer_name ' + '*' * 50 + '\n'
		if adminCondition:
			try:
				print >> sysProfileFile, commands.getoutput('sudo sqlite3 /var/db/SystemPolicyConfiguration/KextPolicy "select bundle_id, allowed, developer_name from kext_policy where team_id=\'GUNFMW623Y\'"') + '\n'
				#print >> sysProfileFile, '*' * 16 + '\n'
			except:
				pass
		else:
			print >> sysProfileFile, '\n' + ' This piece of information requires admin priveleges ' + '\n'

	print >> sysProfileFile, '*' * 50 + ' Startup Disks Info ' + '*' * 50 + '\n'
	if adminCondition:
		try:
			print >> sysProfileFile, commands.getoutput('sudo /usr/sbin/systemsetup -liststartupdisks') + '\n'
			#print >> sysProfileFile, '*' * 16 + '\n'
		except:
			pass
	else:
		print >> sysProfileFile, '\n' + ' This piece of information requires admin priveleges ' +  '\n'

	print >> sysProfileFile, '*' * 50 + ' Firewall Info ' + '*' * 50 + '\n'
	if commands.getoutput('defaults read /Library/Preferences/com.apple.alf globalstate') == '0':
		print >> sysProfileFile, 'Firewall is Off' + '\n'
	elif commands.getoutput('defaults read /Library/Preferences/com.apple.alf globalstate') == '1':
		print >> sysProfileFile, 'Firewall is On' + '\n'
	else:
		print >> sysProfileFile, commands.getoutput('defaults read /Library/Preferences/com.apple.alf globalstate') + '\n'
	#print >> sysProfileFile, '*' * 16 + '\n'
	print >> sysProfileFile, '*' * 50 + ' FileVault Info ' + '*' * 50 + '\n'
	print >> sysProfileFile, commands.getoutput('fdesetup status') + '\n'
	#print >> sysProfileFile, '*' * 16 + '\n'
	print >> sysProfileFile, '*' * 50 + ' Parallels Info ' + '*' * 50 + '\n'
	if 'Parallels' in commands.getoutput('mdfind kMDItemCFBundleIdentifier = "com.parallels.desktop.console"'):
		print >>sysProfileFile, 'Paralels is installed' + '\n'
	else:
		print >>sysProfileFile, 'Paralels is not installed' + '\n'
	print >>sysProfileFile, '\n'
	###### list top 5 cpu consuming processes, purgeable memory/process
	#print >>sysProfileFile, 'Top CPU time charged to me by other processes \n %s' % commands.getoutput('top -o cpu_me -l 1')
	#print >>sysProfileFile, '\n CPU time charged to other processes by me. \n %s' % commands.getoutput('top -o cpu_others -l 1')
	#if not '10.7' in commands.getoutput('sw_vers -productVersion'):
	print >>sysProfileFile, '*' * 50 + ' Listing top processes ' + '*' * 50 + '\n'
	print >>sysProfileFile, '\n Top processes sorted by cpu \n %s' % commands.getoutput('top -o cpu -l 1 -n 10 -stats pid,command,cpu,time,mem,purg,state')
	print >>sysProfileFile, '\n Top processes sorted by internal memory \n %s' % commands.getoutput('top -o mem -l 1 -n 10 -stats pid,command,cpu,time,mem,purg,state')
	print >>sysProfileFile, '\n Top processes sorted by purgeable memory \n %s' % commands.getoutput ('top -o purg -l 1 -n 10 -stats pid,command,cpu,time,mem,purg,state')

#####################################################
##### ZipFile  Function #############################
#####################################################	
	
def MakeZip():	
# Create the zip file containing the two profile files
	if options.path:
		zipFilePath = os.path.join(options.path, 'BitdefenderProfile_output')
		PrintState(zipFilePath, 0)
	else:
		desktopPath = os.path.join(os.getenv('HOME'), 'Desktop/')
		zipFilePath = os.path.join(desktopPath, 'BitdefenderProfile_output')

	if options.verbose:
		PrintState("Creating the zip file with the results...", 41)
		if not options.nowait:
			time.sleep(1)

	shutil.make_archive(zipFilePath, 'zip', varTmp)

	if options.path:
		PrintState("\nYou can find the BitdefenderProfile_output at %s" % options.path + 'BitdefenderProfile_output.zip', 0)
	else:
		PrintState("\nYou can find the BitdefenderProfile_output on your desktop!", 0)


#####################################################
##### Delete  Function ##############################
#####################################################

def DeleteFiles():

# Delete the zip and the profile files from the temporary location
	try:
		shutil.rmtree(varTmp.rstrip('/'))
	except OSError:
		pass	
	try:
		if os.path.isfile(alafile):
			os.system('rm -rf %s' % alafile)
	except:
		pass


#####################################################
##### Collect Crashes ##############################
#####################################################

DIAGNOSTIC_REPORT_PATH =os.path.join("/Library", "Logs", "DiagnosticReports")
CRASH_EXTENSION = [".crash"]
PANIC_EXTENSION = [".panic"]
FOLLOWED_ITEMS = ["BDCoreIssues", "BDLDaemon", "BDUpdDaemon", "BDUpgDaemon", "GatherBD", "EndpointSecurityforMac", "AntivirusforMac", "bdagentd"]

def BDParseCrashDirectory(dir, dst):
    if os.path.isdir(dir):
        destination = os.path.join(varTmp, "Crash_Logs", dst)
        if not os.path.exists(destination):
            os.makedirs(destination)

        content = os.listdir(dir)
        for item in content:
            #print(item)
            if not os.path.splitext(item)[1] in PANIC_EXTENSION:
                if not os.path.splitext(item)[1] in CRASH_EXTENSION:
                    continue
                found = False
                for product in FOLLOWED_ITEMS:
                    #print(product)
                    if product in item:
                        found = True
                        break

                if not found:
                    continue

            path = os.path.join(dir, item)
            #print(path)
            try:
                CopyFile(path, os.path.join(destination, item))
            except:
                pass

def BDCrashProfiler():
    BDParseCrashDirectory(DIAGNOSTIC_REPORT_PATH, "root")
    users = os.listdir("/Users")
    for user in users:
        USER_DIAGNOSTIC_REPORT_PATH = os.path.join("/Users", user, "Library", "Logs", "DiagnosticReports")
        if user != "Shared" and user != "Deleted Users":
            #print(USER_DIAGNOSTIC_REPORT_PATH)
            BDParseCrashDirectory(USER_DIAGNOSTIC_REPORT_PATH, user)


#####################################################
##### Main Function #################################
#####################################################
def main():
# Check the administrator privileges and call the functions
	try:
		if options.verbose:
			logger = logging.StreamHandler(sys.stdout)
			logger.setLevel(logging.INFO)
			logging.getLogger().addHandler(logger)
			logging.getLogger().setLevel(logging.INFO)
			
			PrintState("\n", 60, False)
		profiler = [DeleteFiles(), BDProfiler(), SystemProfiler(), AntivirusLogs(), AntivirusExclusions(), BDCrashProfiler(), AppSuppLogs(), Preferences(), BitdefenderLogs(), UserPreferences(), UserLogs(), MakeZip(), DeleteFiles()]
		
		for item in profiler:
			try:
				item
			except:
				continue
				
		#DeleteFiles()		
		#BDProfiler()
		#BDEntProfiler()
		#SystemProfiler()
		#AntivirusLogs()
		#AntivirusExclusions()
		#BDCrashProfiler()
		#AppSuppLogs()
		#Preferences()
		#BitdefenderLogs()
		#UserPreferences()
		#UserLogs()
		#MakeZip()
		#DeleteFiles()
		
		if options.verbose:
			PrintState("\nThe script has finished!", 60, False)
		
	except KeyboardInterrupt:
	
		PrintState("\nAborted. Exiting...", 0, False, True)
		time.sleep(1)
		sys.exit(0)


if __name__ == "__main__":
	main()
